### Name: mlogit
### Title: Multinomial logit model
### Aliases: mlogit print.mlogit fitted.mlogit residuals.mlogit
###   df.residual.mlogit terms.mlogit model.matrix.mlogit update.mlogit
###   summary.mlogit print.summary.mlogit vcov.mlogit logLik.mlogit
### Keywords: regression

### ** Examples


## Cameron and Trivedi's Microeconometrics p.493
## There are two alternative specific variables : pr (price) and ca (catch)
## and four fishing mode : beach, pier, boat, charter

data("Fishing",package="mlogit")
Fish <- mlogit.data(Fishing,varying=c(4:11),shape="wide",choice="mode")

## a pure "conditional" model without intercepts

summary(mlogit(mode~pr+ca-1,data=Fish))

## a pure "multinomial model"

summary(mlogit(mode~1|income,data=Fish))

## which can also be estimated using multinom (package nnet)

library(nnet)
summary(multinom(mode~income,data=Fishing))

## a "mixed" model

m <- mlogit(mode~pr+ca|income,data=Fish)
summary(m)




